# Shared data handling
This lib simplifies the python code in other projects.

## Installation
````
pip3 install shared-data-handling
````

## Usage
tbd

## Publish
Run ```python -m build```
--> Packages will be stored under dist
Run ```py -m twine upload --repository pypi dist/*```


## ToDos
[ ] [setup a gitlab pipeline](https://docs.gitlab.com/ee/user/packages/pypi_repository/)


## Version History
### Current Version
### 0.01
- Initial Version
